@@ -2499,8 +2499,8 @@ void synthv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 				// filters
 
 				if (dcf1_enabled) {
-					const float env1 = 0.5f * (1.0f + vel1
-						* *m_dcf1.envelope * pv->dcf1_env.tick());
+					const float env1 = 0.5f
+						* (1.0f + *m_dcf1.envelope * pv->dcf1_env.tick());
 					const float cutoff1 = synthv1_sigmoid_1(*m_dcf1.cutoff
 						* env1 * (1.0f + *m_lfo1.cutoff * lfo1));
 					const float reso1 = synthv1_sigmoid_1(*m_dcf1.reso
@@ -2527,8 +2527,8 @@ void synthv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 				}
 
 				if (dcf2_enabled) {
-					const float env2 = 0.5f * (1.0f + vel2
-						* *m_dcf2.envelope * pv->dcf2_env.tick());
+					const float env2 = 0.5f
+						* (1.0f + *m_dcf2.envelope * pv->dcf2_env.tick());
 					const float cutoff2 = synthv1_sigmoid_1(*m_dcf2.cutoff
 						* env2 * (1.0f + *m_lfo2.cutoff * lfo2));
 					const float reso2 = synthv1_sigmoid_1(*m_dcf2.reso
