@@ -1,7 +1,7 @@
 // synthv1widget_env.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
 #include "synthv1widget_env.h"
 
 #include <QPainter>
+#include <QPainterPath>
 #include <QMouseEvent>
 
 #include <math.h>
@@ -38,9 +39,8 @@ inline float safe_value ( float x )
 // synthv1widget_env -- Custom widget
 
 // Constructor.
-synthv1widget_env::synthv1widget_env (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QFrame(pParent, wflags),
+synthv1widget_env::synthv1widget_env ( QWidget *pParent )
+	: QFrame(pParent),
 		m_fAttack(0.0f), m_fDecay(0.0f), m_fSustain(0.0f), m_fRelease(0.0f),
 		m_poly(7), m_iDragNode(-1)
 {
